@@ -6,13 +6,14 @@ Getopt::EX::termcolor - Getopt::EX termcolor module
 
 =head1 VERSION
 
-Version 1.06
+Version 1.07
 
 =head1 SYNOPSIS
 
     use Getopt::EX::Loader;
-    my $rcloader = new Getopt::EX::Loader
-        BASECLASS => [ 'App::command', 'Getopt::EX' ];
+    my $rcloader = Getopt::EX::Loader->new(
+        BASECLASS => [ 'App::command', 'Getopt::EX' ],
+        );
 
     or
 
@@ -119,16 +120,15 @@ as Perl itself.
 
 =cut
 
+use v5.14;
 package Getopt::EX::termcolor;
 
-use v5.14;
-use strict;
+our $VERSION = '1.07';
+
 use warnings;
 use Carp;
 use Data::Dumper;
 
-our $VERSION = "1.06";
-
 use Exporter 'import';
 our @EXPORT      = qw();
 our %EXPORT_TAGS = ();
